==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/edgeorder/kotlin/inputs/TransportPreferencesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.edgeorder.kotlin.inputs

import com.pulumi.azurenative.edgeorder.inputs.TransportPreferencesArgs.builder
import com.pulumi.azurenative.edgeorder.kotlin.enums.TransportShipmentTypes
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Preferences related to the shipment logistics of the sku
 * @property preferredShipmentType Indicates Shipment Logistics type that the customer preferred.
 */
public data class TransportPreferencesArgs(
    public val preferredShipmentType: Output<Either<String, TransportShipmentTypes>>,
) : ConvertibleToJava<com.pulumi.azurenative.edgeorder.inputs.TransportPreferencesArgs> {
    override fun toJava(): com.pulumi.azurenative.edgeorder.inputs.TransportPreferencesArgs =
        com.pulumi.azurenative.edgeorder.inputs.TransportPreferencesArgs.builder()
            .preferredShipmentType(
                preferredShipmentType.applyValue({ args0 ->
                    args0.transform({ args0 ->
                        args0
                    }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            ).build()
}

/**
 * Builder for [TransportPreferencesArgs].
 */
@PulumiTagMarker
public class TransportPreferencesArgsBuilder internal constructor() {
    private var preferredShipmentType: Output<Either<String, TransportShipmentTypes>>? = null

    /**
     * @param value Indicates Shipment Logistics type that the customer preferred.
     */
    @JvmName("sbqmklmfhbwssvic")
    public suspend
    fun preferredShipmentType(`value`: Output<Either<String, TransportShipmentTypes>>) {
        this.preferredShipmentType = value
    }

    /**
     * @param value Indicates Shipment Logistics type that the customer preferred.
     */
    @JvmName("bnxduhdidwilwtel")
    public suspend fun preferredShipmentType(`value`: Either<String, TransportShipmentTypes>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.preferredShipmentType = mapped
    }

    /**
     * @param value Indicates Shipment Logistics type that the customer preferred.
     */
    @JvmName("rvgfltrjneodnqtc")
    public fun preferredShipmentType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, TransportShipmentTypes>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.preferredShipmentType = mapped
    }

    /**
     * @param value Indicates Shipment Logistics type that the customer preferred.
     */
    @JvmName("mhpbbhialwxwdjsr")
    public fun preferredShipmentType(`value`: TransportShipmentTypes) {
        val toBeMapped = Either.ofRight<String, TransportShipmentTypes>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.preferredShipmentType = mapped
    }

    internal fun build(): TransportPreferencesArgs = TransportPreferencesArgs(
        preferredShipmentType = preferredShipmentType ?: throw
            PulumiNullFieldException("preferredShipmentType"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/edgeorder/kotlin/inputs/TransportPreferencesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.edgeorder.kotlin.inputs

import com.pulumi.azurenative.edgeorder.inputs.TransportPreferencesArgs.builder
import com.pulumi.azurenative.edgeorder.kotlin.enums.TransportShipmentTypes
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Preferences related to the shipment logistics of the sku
 * @property preferredShipmentType Indicates Shipment Logistics type that the customer preferred.
 */
public data class TransportPreferencesArgs(
    public val preferredShipmentType: Output<Either<String, TransportShipmentTypes>>,
) : ConvertibleToJava<com.pulumi.azurenative.edgeorder.inputs.TransportPreferencesArgs> {
    override fun toJava(): com.pulumi.azurenative.edgeorder.inputs.TransportPreferencesArgs =
        com.pulumi.azurenative.edgeorder.inputs.TransportPreferencesArgs.builder()
            .preferredShipmentType(
                preferredShipmentType.applyValue({ args0 ->
                    args0.transform({ args0 ->
                        args0
                    }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            ).build()
}

/**
 * Builder for [TransportPreferencesArgs].
 */
@PulumiTagMarker
public class TransportPreferencesArgsBuilder internal constructor() {
    private var preferredShipmentType: Output<Either<String, TransportShipmentTypes>>? = null

    /**
     * @param value Indicates Shipment Logistics type that the customer preferred.
     */
    @JvmName("lkdajmjbnanlckfh")
    public suspend
    fun preferredShipmentType(`value`: Output<Either<String, TransportShipmentTypes>>) {
        this.preferredShipmentType = value
    }

    /**
     * @param value Indicates Shipment Logistics type that the customer preferred.
     */
    @JvmName("jgwgyqudtmgrpwwa")
    public suspend fun preferredShipmentType(`value`: Either<String, TransportShipmentTypes>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.preferredShipmentType = mapped
    }

    /**
     * @param value Indicates Shipment Logistics type that the customer preferred.
     */
    @JvmName("qtvkghpkpsxhonse")
    public fun preferredShipmentType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, TransportShipmentTypes>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.preferredShipmentType = mapped
    }

    /**
     * @param value Indicates Shipment Logistics type that the customer preferred.
     */
    @JvmName("fexindyjougwajdt")
    public fun preferredShipmentType(`value`: TransportShipmentTypes) {
        val toBeMapped = Either.ofRight<String, TransportShipmentTypes>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.preferredShipmentType = mapped
    }

    internal fun build(): TransportPreferencesArgs = TransportPreferencesArgs(
        preferredShipmentType = preferredShipmentType ?: throw
            PulumiNullFieldException("preferredShipmentType"),
    )
}
